@@ -6,13 +6,16 @@ resample <- function(object, # one of the four mgm model objects (mgm, mvar, tvm
                      blocks, # type of resampling for time-series data
                      quantiles,
                      pbar, # progress bar
+                     verbatim,
                      ...)
   
 {
   
+  
   # ----- Fill in defaults -----
   
   if(missing(pbar)) pbar <- TRUE
+  if(missing(verbatim)) verbatim <- FALSE
   if(missing(seeds)) seeds <- 1:nB
   if(missing(blocks)) blocks <- 10
   if(missing(quantiles)) quantiles <- c(0.05, .95)
@@ -75,9 +78,10 @@ resample <- function(object, # one of the four mgm model objects (mgm, mvar, tvm
     
     for(b in 1:nB) {
       
-      set.seed(seeds[b])
+      set.seed(seeds[b]) # for cross validation
+      if(verbatim) print(paste0("Seed = ", seeds[b]))
       tt <- proc.time()[3]
-      
+  
       l_b_models[[b]] <- mgm(data = data[l_ind[[b]], ],
                              type = o_call$type,
                              level = o_call$level,
@@ -164,6 +168,7 @@ resample <- function(object, # one of the four mgm model objects (mgm, mvar, tvm
     for(b in 1:nB) {
       
       set.seed(seeds[b])
+      if(verbatim) print(paste0("Seed = ", seeds[b]))
       tt <- proc.time()[3]
       
       l_b_models[[b]] <- tvmgm(data = data[l_ind[[b]],],
@@ -219,21 +224,26 @@ resample <- function(object, # one of the four mgm model objects (mgm, mvar, tvm
     # --- Define bootstrap samples ---
     
     # Compute design matrix to find out how many rows it has
-    data_lagged <- lagData(data = data, 
-                           lags = o_call$lags, 
+    if(!is.null(o_call$beepvar) & !is.null(o_call$dayvar)) {
+      o_call$consec <- beepday2consec(beepvar = o_call$beepvar,
+                               dayvar = o_call$dayvar)
+    } # if: specification of consecutiveness via beepvar and dayvar
+
+    data_lagged <- lagData(data = data,
+                           lags = o_call$lags,
                            consec = o_call$consec)
     
-    n_design <- nrow(data_lagged$data_response)
-    
+    n_design <- nrow(data_lagged$data_response) # data_response has the first 1:max_lag already excluded; this is not great and should be put into $included at some point
+    ind_valid_rows <-  (1:n_design)[data_lagged$included]
+
     # Take bootstrap sample from rows in design matrix
-    
     l_ind <- list()
     
     for(b in 1:nB) {
       
       set.seed(seeds[b])
       
-      l_ind[[b]] <- sample(x = 1:n_design, 
+      l_ind[[b]] <- sample(x = ind_valid_rows, 
                            size = n_design, 
                            replace = TRUE)
       
@@ -249,6 +259,7 @@ resample <- function(object, # one of the four mgm model objects (mgm, mvar, tvm
     for(b in 1:nB) {
       
       set.seed(seeds[b])
+      if(verbatim) print(paste0("Seed = ", seeds[b]))
       tt <- proc.time()[3]
       
       l_b_models[[b]] <- mvar(data = data, # not changed here because changed via boot_ind inside of mvar()
@@ -299,6 +310,11 @@ resample <- function(object, # one of the four mgm model objects (mgm, mvar, tvm
     # --- Define bootstrap samples ---
     
     # Compute design matrix to find out how many rows it has
+    if(!is.null(o_call$beepvar) & !is.null(o_call$dayvar)) {
+      o_call$consec <- beepday2consec(beepvar = o_call$beepvar,
+                               dayvar = o_call$dayvar)
+    } # if: specification of consecutiveness via beepvar and dayvar
+    
     data_lagged <- lagData(data = data, 
                            lags = o_call$lags, 
                            consec = o_call$consec)
@@ -355,6 +371,7 @@ resample <- function(object, # one of the four mgm model objects (mgm, mvar, tvm
     for(b in 1:nB) {
       
       set.seed(seeds[b])
+      if(verbatim) print(paste0("Seed = ", seeds[b]))
       tt <- proc.time()[3]
       
       l_b_models[[b]] <- tvmvar(data = data, # not changed here because changed via boot_ind inside of mvar() / tvmvar()
@@ -535,7 +552,7 @@ resample <- function(object, # one of the four mgm model objects (mgm, mvar, tvm
   # ----- Return outlist -----
   
   outlist$totalTime <- sum(outlist$Times)
-  class(outlist) <- 'resample'
+  class(outlist) <- c('resample', class(object)[2])
   
   return(outlist)
   
